# Changelog
All notable changes to this project will be documented in this file.
The format is based on [Keep a Changelog](http://keepachangelog.com/) and this project follows [Semantic Versioning](http://semver.org/).

## [Unreleased]

## [0.0.5] - 2022-08-17
### Added
- Add `file` method to generate download URLs for files
- Example code for photo download
- Jupyter example notebook

## [0.0.4] - 2022-08-16
### Changed
- Move `config.yml` to goifer directory

## [0.0.3] - 2022-08-16
### Fixed
- Include `config.yml` in sdist

## [0.0.2] - 2022-08-16
### Fixed
- Use `flit` to publish package to PyPI

## [0.0.1] - 2022-08-16
### Added
- Initial release of goifer


# Categories
- `Added` for new features.
- `Changed` for changes in existing functionality.
- `Deprecated` for once-stable features removed in upcoming releases.
- `Removed` for deprecated features removed in this release.
- `Fixed` for any bug fixes.
- `Security` to invite users to upgrade in case of vulnerabilities.

[Unreleased]: https://github.com/metaodi/goifer/compare/v0.0.5...HEAD
[0.0.5]: https://github.com/metaodi/goifer/compare/v0.0.4...v0.0.5
[0.0.4]: https://github.com/metaodi/goifer/compare/v0.0.3...v0.0.4
[0.0.3]: https://github.com/metaodi/goifer/compare/v0.0.2...v0.0.3
[0.0.2]: https://github.com/metaodi/goifer/compare/v0.0.1...v0.0.2
[0.0.1]: https://github.com/metaodi/goifer/releases/tag/v0.0.1
